@@ -2,7 +2,7 @@
 
 # -----------------------------------------------------------------------------
 
-__version__ = '2.5.8'
+__version__ = '2.5.13'
 
 # -----------------------------------------------------------------------------
 
@@ -169,6 +169,9 @@ class Exchange(BaseExchange):
     async def watch_ticker(self, symbol, params={}):
         raise NotSupported(self.id + '.watch_ticker() not implemented yet')
 
+    async def watch_tickers(self, symbols=None, params={}):
+        raise NotSupported(self.id + '.watch_tickers() not implemented yet')
+
     async def watch_order_book(self, symbol, limit=None, params={}):
         raise NotSupported(self.id + '.watch_order_book() not implemented yet')
 
